<?php
if ( ! function_exists( 'foody_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function foody_setup() {
	
	
	// Add nav menu
	register_nav_menu( 'primary', 'Primary Menu' );
	
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Leto, use a find and replace
	 * to change 'leto' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'foody', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	add_image_size( 'foody-large-thumb', 780 );
	add_image_size( 'foody-medium-thumb', 400 );
    add_image_size( 'thumb-small', 200, 200, true ); // Hard crop to exact dimensions
}
endif;
add_action( 'after_setup_theme', 'foody_setup' );
/**
 * Enqueue scripts and styles. 
 */
function foody_load_style() {
	if ( !is_admin() ) {
		wp_enqueue_style( 'fontawesome-min', get_template_directory_uri() . '/inc/css/font-awesome.min.css', array() );
		if( ( is_home() || is_front_page() ) ) {
		wp_enqueue_style( 'slider-css', get_template_directory_uri().'/inc/css/slider.css' );
		}
		wp_enqueue_style( 'beauty_styles', get_template_directory_uri() . '/css/style.css', array() );
		wp_enqueue_style( 'defaults', get_template_directory_uri() . '/inc/css/defaults.css', array() );
			// Theme custom stylesheet
		wp_enqueue_style( 'custom_styles', get_stylesheet_uri(),false, null);
				// Theme scripts

		wp_enqueue_script( 'main', get_template_directory_uri().'/inc/js/main.js', array('jquery'), null, true );
		wp_enqueue_script( 'isotope.pkgd.min', 'https://unpkg.com/isotope-layout@3.0.4/dist/isotope.pkgd.min.js', array('jquery'), NULL, true);
	}
}
add_action('wp_print_styles', 'foody_load_style');

// Menu walker adding "has-children" class to menu li's with children menu items
class hemingway_nav_walker extends Walker_Nav_Menu {
    function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) {
        $id_field = $this->db_fields['id'];
        if ( !empty( $children_elements[ $element->$id_field ] ) ) {
            $element->classes[] = 'has-children';
        }
        Walker_Nav_Menu::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
    }
}
/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function leto_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'leto' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'leto' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Homepage', 'leto' ),
		'id'            => 'homepage-1',
		'description'   => esc_html__( 'Add widgets here.', 'leto' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	for ( $i=1; $i <= 4; $i++ ) {
		register_sidebar( array(
			'name'          => __( 'Footer ', 'leto' ) . $i,
			'id'            => 'footer-' . $i,
			'description'   => '',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}	
	register_widget( 'Leto_Social' );
}
add_action( 'widgets_init', 'leto_widgets_init' );
/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
/**
 * Theme Functions
 */
require get_template_directory() . '/inc/theme-functions/init.php';
/**
* Load Rezervasyon Page meta box values
*/
require get_template_directory() . '/lib/order-online-CMB.php';
/**
* Load Servislerimiz CMB
*/
require get_template_directory() . '/lib/hizmetlerimiz-CMB.php';
/**
* Load Slider Custom Post Type
*/
require get_template_directory() . '/lib/slider-metabox/slider-metabox.php';
/** captcha icin kullaniyorum, asagidaki kod olmazsa güvenlik kodu
 * yanlis hatasi aliyorum
*/
//redirect to admin dashboard after admin login
global $current_user;	
wp_get_current_user();
$user_id		= $current_user->ID;
if($user_id>0 && $current_user->has_cap('administrator'))
{
	session_start();
	if(isset($_SESSION['redirect_handle_dashboard']) && $_SESSION['redirect_handle_dashboard']=="out")
	{
		$_SESSION['redirect_handle_dashboard'] = "in";
		
	}
}
else
{
	session_start();
	$_SESSION['redirect_handle_dashboard']= "out";
}
//End
/**
 * Widgets
 */
require_once get_template_directory() . '/inc/widgets/class-leto-social.php';
require_once get_template_directory() . '/inc/widgets/popular-post-widget.php';
	// utility function for recent popular posts
	include_once( 'inc/widgets/function/gdlr-media.php');
	include_once( 'inc/widgets/function/gdlr-utility.php');?>